@@ -35,7 +35,7 @@ import re
 
 PY2 = sys.version_info[0] == 2
 
-VERSION = (0, 2, 1)
+VERSION = (0, 2, 2)
 __version__ = '%s.%s.%s' % VERSION
 apilevel = '2.0'
 threadsafety = 1
@@ -47,8 +47,8 @@ def DEBUG_OUTPUT(*argv):
     if not DEBUG:
         return
     for s in argv:
-        print(s, end=' ', file=sys.stderr)
-    print(file=sys.stderr)
+        print(s, end=' ', file=sys.stdout)
+    print(file=sys.stdout)
 
 Date = datetime.date
 Time = datetime.time
@@ -302,6 +302,8 @@ class Error(Exception):
         self._message = message
     def __str__(self):
         return self._errcode + u":" + self._message
+    def __repr__(self):
+        return self._errcode + u":" + self._message
 
 class InterfaceError(Error):
     pass
@@ -376,7 +378,11 @@ class Cursor(object):
         self._current_row = -1
         self.query = query
         self.args = args
-        self.connection.execute(self, query, args)
+        if args:
+            escaped_args = tuple(escape_parameter(arg) for arg in args)
+            query = query.replace('%', '%%').replace('%%s', '%s')
+            query = query % escaped_args
+        self.connection.execute(query, self)
 
     def executemany(self, query, seq_of_params):
         DEBUG_OUTPUT('Cursor::executemany()', query, seq_of_params)
@@ -441,6 +447,7 @@ class Connection(object):
         self._flush()
 
     def _process_messages(self, obj=None):
+        err = None
         while True:
             code = self._read(1)
             ln = _bytes_to_bint(self._read(4)) - 4
@@ -460,7 +467,7 @@ class Connection(object):
                     hash2 = hashlib.md5(hash1+salt).hexdigest().encode("ascii")
                     self._send_message(PG_F_PASSWORD_MESSAGE, b'md5'+hash2+'\x00')
                 else:
-                    raise InterfaceError("Authentication method %d not supported." % (auth_method,))
+                    err = InterfaceError("Authentication method %d not supported." % (auth_method,))
             elif code == PG_B_PARAMETER_STATUS:
                 k, v, _ = data.split(b'\x00')
                 k = k.decode('ascii')
@@ -472,37 +479,41 @@ class Connection(object):
                 DEBUG_OUTPUT("BACKEND_KEY_DATA:", binascii.b2a_hex(data))
             elif code == PG_B_COMMAND_COMPLETE:
                 command = data[:-1].decode('ascii')
-                for k in ('SELECT', 'UPDATE', 'DELETE', 'INSERT'):
-                    if command[:len(k)] == k:
-                        obj.rowcount = int(data[:-1].decode('ascii').split(' ')[-1])
-                        obj._current_row = -1
-                DEBUG_OUTPUT("COMMAND_COMPLETE:", data[:-1].decode('ascii'))
+                DEBUG_OUTPUT("COMMAND_COMPLETE:", command)
+                if command == 'SHOW':
+                    obj.rowcount = 1
+                    obj._current_row = -1
+                else:
+                    for k in ('SELECT', 'UPDATE', 'DELETE', 'INSERT'):
+                        if command[:len(k)] == k:
+                            obj.rowcount = int(command.split(' ')[-1])
+                            obj._current_row = -1
+                            break
             elif code == PG_B_ROW_DESCRIPTION:
                 DEBUG_OUTPUT("ROW_DESCRIPTION:", binascii.b2a_hex(data))
-                if obj is not None:
-                    count = _bytes_to_bint(data[0:2])
-                    obj.description = [None] * count
-                    n = 2
-                    idx = 0
-                    for i in range(count):
-                        name = data[n:n+data[n:].find(b'\x00')]
-                        n += len(name) + 1
-                        table_oid = _bytes_to_bint(data[n:n+4])
-                        table_pos = _bytes_to_bint(data[n+4:n+6])
-                        modifier = _bytes_to_bint(data[n+12:n+16]),     # modifier
-                        format = _bytes_to_bint(data[n+16:n+18]),       # format
-                        field = (
-                            name,
-                            _bytes_to_bint(data[n+6:n+10]),     # type oid
-                            None,
-                            _bytes_to_bint(data[n+10:n+12]),    # size
-                            None,
-                            None,
-                            None,
-                        )
-                        n += 18
-                        obj.description[idx] = field
-                        idx += 1
+                count = _bytes_to_bint(data[0:2])
+                obj.description = [None] * count
+                n = 2
+                idx = 0
+                for i in range(count):
+                    name = data[n:n+data[n:].find(b'\x00')]
+                    n += len(name) + 1
+                    table_oid = _bytes_to_bint(data[n:n+4])
+                    table_pos = _bytes_to_bint(data[n+4:n+6])
+                    modifier = _bytes_to_bint(data[n+12:n+16]),     # modifier
+                    format = _bytes_to_bint(data[n+16:n+18]),       # format
+                    field = (
+                        name,
+                        _bytes_to_bint(data[n+6:n+10]),     # type oid
+                        None,
+                        _bytes_to_bint(data[n+10:n+12]),    # size
+                        None,
+                        None,
+                        None,
+                    )
+                    n += 18
+                    obj.description[idx] = field
+                    idx += 1
                 DEBUG_OUTPUT('\t\t', obj.description)
             elif code == PG_B_DATA_ROW:
                 DEBUG_OUTPUT("DATA_ROW:", binascii.b2a_hex(data))
@@ -534,9 +545,9 @@ class Connection(object):
                 errcode = err[1][1:].decode(self.encoding)
                 message = err[2][1:].decode(self.encoding)
                 if errcode[:2] == u'23':
-                    raise IntegrityError(errcode, message)
+                    err = IntegrityError(errcode, message)
                 else:
-                    raise ProgrammingError(errcode, message)
+                    err = ProgrammingError(errcode, message)
             elif code == PG_B_COPY_OUT_RESPONSE:
                 is_binary = data[0] == '\x01'
                 num_columns = _bytes_to_bint(data[1:3])
@@ -561,6 +572,8 @@ class Connection(object):
                 self._flush()
             else:
                 DEBUG_OUTPUT("SKIP:", code, ln, binascii.b2a_hex(data))
+        if err:
+            raise err
         return
 
     def __enter__(self):
@@ -597,7 +610,6 @@ class Connection(object):
             b'\x00',
         ])
         self._write(_bint_to_bytes(len(v) + 4, 4) + v)
-        self._cursor = self.cursor()
         self._process_messages()
 
     def _is_connect(self):
@@ -610,11 +622,7 @@ class Connection(object):
     def cursor(self):
         return Cursor(self)
 
-    def execute(self, obj, query, args=()):
-        if args:
-            escaped_args = tuple(escape_parameter(arg) for arg in args)
-            query = query.replace('%', '%%').replace('%%s', '%s')
-            query = query % escaped_args
+    def execute(self, query, obj):
         if not self.in_transaction:
             self._send_message(PG_F_QUERY, b"BEGIN\x00")
             self._process_messages(obj)
@@ -634,19 +642,19 @@ class Connection(object):
     def begin(self):
         DEBUG_OUTPUT('BEGIN')
         self._send_message(PG_F_QUERY, b"BEGIN\x00")
-        self._process_messages(self._cursor)
+        self._process_messages()
 
     def commit(self):
         DEBUG_OUTPUT('COMMIT')
         self._send_message(PG_F_QUERY, b"COMMIT\x00")
-        self._process_messages(self._cursor)
+        self._process_messages()
         self.begin()
 
     def rollback(self):
         DEBUG_OUTPUT('ROLLBACK')
         if self.sock:
             self._send_message(PG_F_QUERY, b"ROLLBACK\x00")
-            self._process_messages(self._cursor)
+            self._process_messages()
             self.begin()
 
     def reopen(self):
